#!/bin/bash


DEFAULT_PRIVATE_KEY_PATH="/home/$USER/.ssh/id_rsa"
DEFAULT_SSH_PORT="22"

echo "--- Bonjour!"
echo "Ce script a pour but final déployer un cluster Kubernetes pour héberger les missions Deadlock sur votre infrastructure."
echo "Avant tout il vous faut renseigner quelques informations sur les machines qui vont nous servir d'hôtes..."
echo "Pour rappel, il nous faut une machine master et une machine esclave : pod"


echo "------------------------------------------------------"
echo "------------------ Informations relatives au master"
echo "[MASTER]"
echo ""
read -p "IP :" ipHostMaster
read -p "Port ssh ( 22 ):" sshPortMaster

if [ -z $sshPortMaster ]
then
  sshPortMaster=$DEFAULT_SSH_PORT
fi

read -p "Chemin vers la clé privée ssh ( ~/.ssh/id_rsa ) :" sshKeyMaster

if [ -z $sshKeyMaster ]
then
  sshKeyMaster=$DEFAULT_PRIVATE_KEY_PATH
fi

read -p "Utilisateur ayant les droits root ( root ) :" ${userMaster:=root}

echo "------------------------------------------------------"
echo "------------------ Informations relatives au pod"
echo "[POD]"
echo ""
read -p "IP : " ipHostPod
read -p "Port ssh ( 22 ) :" sshPortPod

if [ -z $sshPortPod ]
then
  sshPortPod=$DEFAULT_SSH_PORT
fi

read -p "Chemin vers la clé ssh ( ~/.ssh/id_rsa) :" sshKeyPod

if [ -z $sshKeyPod ]
then
  sshKeyPod=$DEFAULT_PRIVATE_KEY_PATH
fi

read -p "Utilisateur ayant les droits root ( root ) :" ${userPod:=root}
echo ""
echo "Merci et c'est parti !!"

touch ./ansible/inventories/build.yml
echo "prod:
  hosts:
    master:
      ansible_host: $ipHostMaster
      ansible_port: $sshPortMaster
      ansible_ssh_private_key_file: \"$sshKeyMaster\"
      ansible_become_user: $userMaster
    pods:
      ansible_host: $ipHostPod
      ansible_port: $sshPortPod
      ansible_ssh_private_key_file: \"$sshKeyPod\"
      ansible_become_user: $userPod
  vars:
    ansible_user: $userMaster
    base_python_package: \"{{ ansible_python_interpreter | default('/usr/bin/python') | basename }}\"" >> ./ansible/inventories/build.yml

ansible-playbook -i ansible/inventories/build.yml ansible/playbook-deploy.yml
rm -f ansible/inventories/build.yml

clear

echo "Entrez les informations suivantes dans la catégorie \"Auto-Hébergé\" de Deadlock"
echo ""
echo "Cluster URL"
echo ""
echo "https://$ipHostMaster:6443"
echo ""
read -p 'Entrée pour afficher la suite'

echo "CA Certificate Data"
echo ""
ssh $userMaster@$ipHostMaster -p $sshPortMaster 'cat /etc/kubernetes/pki/ca.crt'
echo ""
read -p 'Entrée pour afficher la suite'

echo "Client certificate Data"
echo ""
ssh $userMaster@$ipHostMaster -p $sshPortMaster 'cat /etc/kubernetes/pki/deadlock.crt'
echo ""
read -p 'Entrée pour afficher la suite'

echo "Client Key Data"
echo ""
ssh $userMaster@$ipHostMaster -p $sshPortMaster 'cat /etc/kubernetes/pki/deadlock.key'
echo ""
echo "Vous avez maintenant tout ce qu'il vous faut pour permettre à Deadlock de se connecter à votre cluster !"